@@ -1,6 +1,6 @@
 package App::GitGot;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::VERSION = '1.336';
+$App::GitGot::VERSION = '1.337';
 # ABSTRACT: A tool to make it easier to manage multiple git repositories.
 use 5.014;
 use warnings;
@@ -22,7 +22,7 @@ App::GitGot - A tool to make it easier to manage multiple git repositories.
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 SYNOPSIS
 
@@ -30,11 +30,11 @@ See C<perldoc got> for usage information.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
