@@ -1,12 +1,12 @@
 package App::GitGot::Command;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::VERSION = '1.336';
+$App::GitGot::Command::VERSION = '1.337';
 # ABSTRACT: Base class for App::GitGot commands
 use 5.014;
 
 use App::Cmd::Setup -command;
 use Cwd;
-use File::HomeDir;
+use File::HomeDir::Tiny ();
 use List::Util              qw/ max first /;
 use Path::Tiny;
 use Try::Tiny;
@@ -28,7 +28,7 @@ sub opt_spec {
     [ 'all|a'            => 'use all available repositories' ] ,
     [ 'by_path|p'        => 'if set, output will be sorted by repo path (default: sort by repo name)' ] ,
     [ 'color_scheme|c=s' => 'name of color scheme to use' => { default => 'dark' } ] ,
-    [ 'configfile|f=s'   => 'path to config file' => { default => path( File::HomeDir->my_home() , '.gitgot') , required => 1 } ] ,
+    [ 'configfile|f=s'   => 'path to config file' => { default => path( File::HomeDir::Tiny::home() , '.gitgot') , required => 1 } ] ,
     [ 'no_color|C'       => 'do not use colored output' => { default => 0 } ] ,
     [ 'quiet|q'          => 'keep it down' ] ,
     [ 'skip_tags|T=s@'   => 'select repositories not tagged with these words' ] ,
@@ -586,7 +586,7 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 METHODS
 
@@ -618,11 +618,11 @@ Dumps configuration out to disk.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
