@@ -1,6 +1,6 @@
 package App::GitGot::Command::clone;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::clone::VERSION = '1.336';
+$App::GitGot::Command::clone::VERSION = '1.337';
 # ABSTRACT: clone a remote repo and add it to your config
 use 5.014;
 
@@ -19,7 +19,8 @@ use namespace::autoclean;
 sub options {
   my( $class , $app ) = @_;
   return (
-    [ 'defaults|D' => 'use the default choices for all prompts' ] ,
+    [ 'defaults|D'  => 'use the default choices for all prompts' ] ,
+    [ 'recursive|r' => 'clone submodules recursively' => { default => 0 } ],
   );
 }
 
@@ -62,7 +63,10 @@ sub _execute {
   $new_entry->{tags} = $tags if $tags;
 
   say "Cloning into '$path'..." unless $self->quiet;
-  $new_entry->clone( $repo , $path );
+  $new_entry->clone(
+    { recursive => $self->opt->recursive },
+    $repo , $path
+  );
 
   $self->add_repo( $new_entry );
   $self->write_config;
@@ -82,7 +86,7 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 SYNOPSIS
 
@@ -94,13 +98,16 @@ version 1.336
     # using defaults for all prompts
     $ got clone -D <git repo url>
 
+    # recursively clone the submodules as well
+    $ got clone -r <git repo url>
+
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
