@@ -1,6 +1,6 @@
 package App::GitGot::Command::lib;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::lib::VERSION = '1.336';
+$App::GitGot::Command::lib::VERSION = '1.337';
 # ABSTRACT: Generate a lib listing off a .gotlib file
 use 5.014;
 
@@ -75,7 +75,7 @@ App::GitGot::Command::lib - Generate a lib listing off a .gotlib file
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 SYNOPSIS
 
@@ -154,11 +154,11 @@ File containing the list of directories to include. Defaults to I<.gotlib>.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
