@@ -1,6 +1,6 @@
 package App::GitGot::Command::milk;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::milk::VERSION = '1.336';
+$App::GitGot::Command::milk::VERSION = '1.337';
 use 5.014;
 
 # ABSTRACT: well, do you?
@@ -41,15 +41,15 @@ App::GitGot::Command::milk - well, do you?
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
