@@ -1,6 +1,6 @@
 package App::GitGot::Command::tag;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Command::tag::VERSION = '1.336';
+$App::GitGot::Command::tag::VERSION = '1.337';
 # ABSTRACT: list/add/remove tags for the current repository
 use 5.014;
 
@@ -85,7 +85,7 @@ App::GitGot::Command::tag - list/add/remove tags for the current repository
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 SYNOPSIS
 
@@ -125,11 +125,11 @@ Removes tags from the current repository.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
