@@ -1,6 +1,6 @@
 package App::GitGot::Outputter;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Outputter::VERSION = '1.336';
+$App::GitGot::Outputter::VERSION = '1.337';
 # ABSTRACT: Generic base class for outputting formatted messages.
 use 5.014;
 
@@ -65,7 +65,7 @@ App::GitGot::Outputter - Generic base class for outputting formatted messages.
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 ATTRIBUTES
 
@@ -93,11 +93,11 @@ Display a message using the 'color_warning' color settings.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
