@@ -1,6 +1,6 @@
 package App::GitGot::Outputter::dark;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Outputter::dark::VERSION = '1.336';
+$App::GitGot::Outputter::dark::VERSION = '1.337';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
 use 5.014;
 
@@ -51,17 +51,17 @@ App::GitGot::Outputter::dark - Color scheme appropriate for dark terminal backgr
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =for Pod::Coverage color_error color_major_change color_minor_change color_warning
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
