@@ -1,6 +1,6 @@
 package App::GitGot::Repo;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Repo::VERSION = '1.336';
+$App::GitGot::Repo::VERSION = '1.337';
 # ABSTRACT: Base repository objects
 use 5.014;
 
@@ -137,7 +137,7 @@ App::GitGot::Repo - Base repository objects
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 ATTRIBUTES
 
@@ -188,11 +188,11 @@ Passing a tag that is not on the current repo object will silently no-op.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
