@@ -1,6 +1,6 @@
 package App::GitGot::Repo::Git;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Repo::Git::VERSION = '1.336';
+$App::GitGot::Repo::Git::VERSION = '1.337';
 # ABSTRACT: Git repo objects
 use 5.014;
 
@@ -112,7 +112,7 @@ App::GitGot::Repo::Git - Git repo objects
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 METHODS
 
@@ -128,11 +128,11 @@ branch doesn't have a remote.)
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
