@@ -1,6 +1,6 @@
 package App::GitGot::Types;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGot::Types::VERSION = '1.336';
+$App::GitGot::Types::VERSION = '1.337';
 # ABSTRACT: GitGot type library
 use 5.014;    ## strict, unicode_strings
 use warnings;
@@ -33,15 +33,15 @@ App::GitGot::Types - GitGot type library
 
 =head1 VERSION
 
-version 1.336
+version 1.337
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
